@@ -75,11 +75,8 @@ sub dbas_orac {
 sub selected_dba {
    ($top,$dbh) = @_;
    $dbaed_bit = $dbaed_list->get('active');
-   $max_width_of_form = 30;
-   $max_height_of_form = 10;
-   $helvet_10 = '-adobe-helvetica-bold-r-normal--10-80-75-75-p-46-*-1';
-   $helvet_14 = '-adobe-helvetica-bold-r-narrow--14-120-75-75-p-46-*-1';
-   $helvet_18 = '-adobe-helvetica-bold-r-narrow--18-120-75-75-p-46-*-1';
+   $max_width_of_form = 24;
+   $max_height_of_form = 8;
 
    $main_uni_title = "Orac DBA Form for $dbaed_bit";
    my $build_dialog = $top->DialogBox( 
@@ -88,12 +85,11 @@ sub selected_dba {
    my $label = $build_dialog->Label( 
          text   => "Provide SQL for Columns, indicate " .
                    "selection order & then press 'Select Information'",
-         font   => $helvet_14,
          anchor => 'n',
          height => 1);
    $label->pack();
    my $tiler = $build_dialog->Scrolled('Tiler');
-   $tiler->configure(-rows => 10, -columns => 5);
+   $tiler->configure(-rows => $max_height_of_form, -columns => 4);
 
    my $v_command = orac_Utils::file_string('sql_files', 'orac_DBAViewer',
                                            'selected_dba','1','sql');
@@ -105,24 +101,16 @@ sub selected_dba {
    (@global_pl) = qw/-side left -pady 2 -anchor w/;
    $tiler->Manage( $tiler->Label(
                       -text     => 'Order By',
-                      -font => $helvet_10,
                       -relief   => 'groove')->pack(@global_pl));
    $tiler->Manage( $tiler->Label(
                       -text     => 'Column',
-                      -font => $helvet_10,
                       -relief   => 'groove')->pack(@global_pl));
    $tiler->Manage( $tiler->Label(
                       -text     => 'Select SQL',
-                      -font => $helvet_10,
                       -relief   => 'groove')->pack(@global_pl));
    $tiler->Manage( $tiler->Label(
                       -text     => 'Datatype',
-                      -font => $helvet_10,
                       -relief   => 'groove')->pack(@global_pl));
-   $tiler->Manage( $tiler->Label(
-                      -text     => 'Nullable',
-                      -font => $helvet_10,
-	                 -relief   => 'groove')->pack(@global_pl));
    @ind_use_cols;
    @ind_actual_cols;
    my @v_this_text;
@@ -135,7 +123,6 @@ sub selected_dba {
 	                        -relief   => 'flat')->pack(@global_pl));
       $tiler->Manage( $tiler->Label(
                                 -text   => $v_this_text[0],
-                                -font   =>  $helvet_10,
 	                        -relief => 'flat')->pack(@global_pl));
       $sql_entry[$ind_build_count] = "";
 
@@ -144,12 +131,7 @@ sub selected_dba {
          -background => 'white',
          -foreground => 'black'));
       $tiler->Manage( $tiler->Label(
-         -text     => $v_this_text[1],
-         -font =>  $helvet_10,
-	 -relief   => 'flat')->pack(@global_pl));
-      $tiler->Manage( $tiler->Label(
-         -text     => $v_this_text[2],
-         -font =>  $helvet_10,
+         -text     => "$v_this_text[1] $v_this_text[2]",
 	 -relief   => 'flat')->pack(@global_pl));
 
       $ind_actual_cols[$ind_build_count] = "$v_this_text[0]";
@@ -163,7 +145,6 @@ sub selected_dba {
    my $bot_bar = $build_dialog->Frame->pack(@layout_bot_bar);
    $help_button = 
       $bot_bar->Button( text    => '  Help on Select SQL  ',
-       font    => $helvet_18,
        command => sub { $build_dialog->Busy;
                         orac_UnixHelp::help_orac(
                                   $build_dialog,
@@ -175,7 +156,6 @@ sub selected_dba {
 
    $go_button = $bot_bar->Button( 
                     text    => '  Select Information  ',
-                    font    => $helvet_18,
                     command => sub { 
                        $build_dialog->Busy;
                        orac_DBAViewer::selector();
@@ -284,7 +264,6 @@ sub and_finally {
    my $top_frame = $curr_dialog->Frame->pack(@layout_top_bar);
    my $top_label = $top_frame->Label( 
                  -text   => "$dbaed_bit Selection Results: ",
-                 -font   => $helvet_14,
                  -anchor => 'w')->pack(-side => 'left', -anchor => 'w');
 
    my $fancy_width = 80;
@@ -308,7 +287,6 @@ sub and_finally {
    }
    my $num_label = $top_frame->Label( 
                  -textvariable   => \$current_counter,
-                 -font           => $helvet_14,
                  -relief         => 'sunken',
                  -anchor         => 'e',
                  -height         => 1)->pack(-side => 'right', -anchor => 'e');
@@ -339,7 +317,6 @@ sub and_finally {
       }
       $tiler->Manage( $tiler->Label(
                                 -text     => $ind_actual_cols[$i],
-                                -font     =>  $helvet_10,
 	                        -relief   => 'groove')->pack(@global_pl));
       my $super_length;
       my $super_width;
@@ -431,8 +408,7 @@ sub and_finally {
 
    $record_label = "Record of " . ($max_row + 1);
    $generic_scale = $control_bar->Scale( -orient => horizontal, 
-                                         -length => 400, 
-                                         -font   => $helvet_14,
+                                         -length => 200, 
                                          -label  => $record_label,
                                          -sliderrelief => 'raised',
                                          -from   => 1,
@@ -558,7 +534,6 @@ sub now_build_ord {
 
    my $label = $bot_dialog->Label( 
         text   => "Please Arrange Index Order and then press 'Continue'",
-        font =>  $helvet_14,
         anchor => 'n',
         height => 1);
 
@@ -570,19 +545,16 @@ sub now_build_ord {
       if ($i <= $total_ind_count){
          $tiler->Manage( $tiler->Label(
                             -text     => "Order Position $i",
-                            -font => $helvet_10,
                             -relief   => 'groove')->pack(@global_pl));
       }
       else {
          if ($i == ($total_ind_count + 1)){
             $tiler->Manage( $tiler->Label(
                             -text     => "Column",
-                            -font => $helvet_10,
                             -relief   => 'groove')->pack(@global_pl));
          } else {
             $tiler->Manage( $tiler->Label(
                             -text     => "Descending?",
-                            -font => $helvet_10,
                             -relief   => 'groove')->pack(@global_pl));
          }
       }
@@ -603,7 +575,6 @@ sub now_build_ord {
             if ($jesus_column == ($total_ind_count + 1)){
                $tiler->Manage( $tiler->Label(
                                   -text     => $total_ind_array[$jesus_row],
-                                  -font => $helvet_10,
                                   -justify  => 'left',
                                   -relief   => 'flat')->pack(@global_pl));
             } else {
