@@ -1,7 +1,7 @@
 #!/bin/sh
 
-cd $HOME/ORAC-DBA-0.01
+cd $HOME/ORAC-DBA-0.02
 ORACLE_HOME=/os/804
 export ORACLE_HOME
 
-./orac_dba.pl &
+perl orac_dba.pl &
